@@ -1,5 +1,5 @@
 # typedload
-# Copyright (C) 2018 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2019 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
 
+import datetime
 from enum import Enum
 from typing import Dict, List, NamedTuple, Optional, Set, Tuple, Union
 import unittest
@@ -94,7 +95,6 @@ class TestUnion(unittest.TestCase):
         assert type(loader.load({'val': {'a': 1}}, C).val) == A
         assert type(loader.load({'val': {'a': '1'}}, C).val) == B
 
-
     def test_optional(self):
         loader = dataloader.Loader()
         assert loader.load(1, Optional[int]) == 1
@@ -122,6 +122,31 @@ class TestUnion(unittest.TestCase):
         assert loader.load(None, Optional[str]) is None
 
 
+class TestTupleLoad(unittest.TestCase):
+
+    def test_ellipsis(self):
+        loader = dataloader.Loader()
+
+        l = list(range(33))
+        t = tuple(l)
+        assert loader.load(l, Tuple[int, ...]) == t
+        assert loader.load('abc', Tuple[str, ...]) == ('a', 'b', 'c')
+        assert loader.load('a', Tuple[str, ...]) == ('a', )
+
+    def test_tuple(self):
+        loader = dataloader.Loader()
+
+        with self.assertRaises(ValueError):
+            assert loader.load([1], Tuple[int, int]) == (1, 2)
+
+        assert loader.load([1, 2, 3], Tuple[int, int]) == (1, 2)
+        loader.failonextra = True
+        # Now the same will fail
+        with self.assertRaises(ValueError):
+            loader.load([1, 2, 3], Tuple[int, int]) == (1, 2)
+
+
+
 class TestNamedTuple(unittest.TestCase):
 
     def test_simple(self):
@@ -282,3 +307,14 @@ class TestExceptions(unittest.TestCase):
         except Exception as e:
             assert e.value == 'q'
             assert e.type_ == int
+
+
+class TestDatetime(unittest.TestCase):
+
+    def test_date(self):
+        loader = dataloader.Loader()
+        assert loader.load((2011, 1, 1), datetime.date) == datetime.date(2011, 1, 1)
+        assert loader.load((15, 33), datetime.time) == datetime.time(15, 33)
+        assert loader.load((15, 33, 0), datetime.time) == datetime.time(15, 33)
+        assert loader.load((2011, 1, 1), datetime.datetime) == datetime.datetime(2011, 1, 1)
+        assert loader.load((2011, 1, 1, 22), datetime.datetime) == datetime.datetime(2011, 1, 1, 22)
