@@ -21,8 +21,11 @@ Module to load data into typed data structures
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
 
+import datetime
 from enum import Enum
 from typing import *
+# It is for some reason not imported with * on Python 3.5.2
+from typing import FrozenSet
 
 from .exceptions import *
 from .typechecks import *
@@ -158,9 +161,11 @@ class Loader:
             (is_list, _listload),
             (is_dict, _dictload),
             (is_set, _setload),
+            (is_frozenset, _frozensetload),
             (is_namedtuple, _namedtupleload),
             (is_dataclass, _namedtupleload),
             (is_forwardref, _forwardrefload),
+            (lambda type_: type_ in {datetime.date, datetime.time, datetime.datetime}, _datetimeload),
         ]  # type: List[Tuple[Callable[[Type[T]], bool], Callable[['Loader', Any, Type[T]], T]]]
 
         for k, v in kwargs.items():
@@ -292,6 +297,14 @@ def _setload(l: Loader, value, type_) -> Set:
     return {l.load(i, t) for i in value}
 
 
+def _frozensetload(l: Loader, value, type_) -> FrozenSet:
+    """
+    This loads into something like FrozenSet[int]
+    """
+    t = type_.__args__[0]
+    return frozenset(l.load(i, t) for i in value)
+
+
 def _tupleload(l: Loader, value, type_) -> Tuple:
     """
     This loads into something like Tuple[int,str]
@@ -300,12 +313,15 @@ def _tupleload(l: Loader, value, type_) -> Tuple:
         args = type_.__args__
     else:
         args = type_.__tuple_params__
-    if l.failonextra and len(value) > len(args):
-        raise TypedloadValueError('Value is too long for type %s' % type_, value=value, type_=type_)
-    elif len(value) < len(args):
-        raise TypedloadValueError('Value is too short for type %s' % type_, value=value, type_=type_)
 
-    return tuple(l.load(v, t, annotation=Annotation(AnnotationType.INDEX, i)) for i, (v, t) in enumerate(zip(value, args)))
+    if len(args) == 2 and args[1] == ...: # Tuple[something, ...]
+        return tuple(l.load(i, args[0]) for i in value)
+    else: # Tuple[something, something, somethingelse]
+        if l.failonextra and len(value) > len(args):
+            raise TypedloadValueError('Value is too long for type %s' % type_, value=value, type_=type_)
+        elif len(value) < len(args):
+            raise TypedloadValueError('Value is too short for type %s' % type_, value=value, type_=type_)
+        return tuple(l.load(v, t, annotation=Annotation(AnnotationType.INDEX, i)) for i, (v, t) in enumerate(zip(value, args)))
 
 
 def _namedtupleload(l: Loader, value: Dict[str, Any], type_) -> Tuple:
@@ -320,8 +336,27 @@ def _namedtupleload(l: Loader, value: Dict[str, Any], type_) -> Tuple:
         #dataclass
         import dataclasses
         fields = set(type_.__dataclass_fields__.keys())
-        optional_fields ={k for k,v in type_.__dataclass_fields__.items() if not (isinstance(getattr(v, 'default', dataclasses._MISSING_TYPE()), dataclasses._MISSING_TYPE) and isinstance(getattr(v, 'default_factory', dataclasses._MISSING_TYPE()), dataclasses._MISSING_TYPE))}
+        optional_fields = {k for k,v in type_.__dataclass_fields__.items() if not (isinstance(getattr(v, 'default', dataclasses._MISSING_TYPE()), dataclasses._MISSING_TYPE) and isinstance(getattr(v, 'default_factory', dataclasses._MISSING_TYPE()), dataclasses._MISSING_TYPE))}
         type_hints = {k: v.type for k,v in type_.__dataclass_fields__.items()}
+
+        #Name mangling
+
+        # Prepare the list of the needed name changes
+        transforms = []  # type: List[Tuple[str, str]]
+        for field in fields:
+            if type_.__dataclass_fields__[field].metadata:
+                name = type_.__dataclass_fields__[field].metadata.get('name')
+                if name:
+                    transforms.append((field, name))
+        # Do the needed name changes
+        if transforms:
+            value = value.copy()
+            for pyname, dataname in transforms:
+                if dataname in value:
+                    tmp = value[dataname]
+                    del value[dataname]
+                    value[pyname] = tmp
+
     necessary_fields = fields.difference(optional_fields)
     try:
         vfields = set(value.keys())
@@ -436,3 +471,7 @@ def _noneload(l: Loader, value, type_) -> None:
     if value is None:
         return None
     raise TypedloadValueError('Not None', value=value, type_=type_)
+
+
+def _datetimeload(l: Loader, value, type_) -> Union[datetime.date, datetime.time, datetime.datetime]:
+    return type_(*value)
