@@ -33,7 +33,26 @@ different versions of Python.
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
 from enum import Enum
-from typing import Any, Tuple, Union, Set, List, Dict, Type
+from typing import Any, Tuple, Union, Set, List, Dict, Type, FrozenSet
+
+
+__all__ = [
+    'is_attrs',
+    'is_dataclass',
+    'is_dict',
+    'is_enum',
+    'is_forwardref',
+    'is_frozenset',
+    'is_list',
+    'is_namedtuple',
+    'is_nonetype',
+    'is_set',
+    'is_tuple',
+    'is_union',
+    'NONETYPE',
+    'HAS_TUPLEARGS',
+    'HAS_UNIONSUBCLASS',
+]
 
 
 try:
@@ -130,6 +149,14 @@ def is_set(type_: Type[Any]) -> bool:
     return _generic_type_check(type_, set, Set)
 
 
+def is_frozenset(type_: Type[Any]) -> bool:
+    '''
+    FrozenSet[A]
+    FrozenSet
+    '''
+    return _generic_type_check(type_, frozenset, FrozenSet)
+
+
 def is_enum(type_: Type[Any]) -> bool:
     '''
     Check if the class is a subclass of Enum
